#ifndef NT2_INCLUDE_FUNCTIONS_ILOG2_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ILOG2_HPP_INCLUDED

#include <nt2/bitwise/include/functions/ilog2.hpp>

#endif
